;***********************************************************
; File Name:	 Ch2_e11.asm
; Target System: C24x Evaluation Board
;
; Description:	 This program transfers a block of data from 
;		 the data memory to a another location in 
;		 data memory. 
;***********************************************************
	
               .include	f240regs.h

TABLEA		.set	8310h	;Starting address of the
                               	;source table	
TABLEB		.set	8410h	;Starting address of the
                              	;destination table	
COUNT		.set	10	;Defines the number of entries
                              	;in the table
;-----------------------------------------------------------
; Variable Declarations for on chip RAM Blocks
;-----------------------------------------------------------		
	.bss	GPR0,1		;General purpose register.
;-----------------------------------------------------------;
; Vector address declarations
;-----------------------------------------------------------		
	.sect	".vectors"

RSVECT		B    START	; Reset Vector
INT1	  	B    PHANTOM	; Interrupt Level 1
INT2	  	B    PHANTOM	; Interrupt Level 2
INT3	  	B    PHANTOM	; Interrupt Level 3
INT4	  	B    PHANTOM	; Interrupt Level 4
INT5	  	B    PHANTOM	; Interrupt Level 5
INT6	  	B    PHANTOM	; Interrupt Level 6
RESERVED  	B    PHANTOM	; Reserved
SW_INT8   	B    PHANTOM	; User S/W Interrupt
SW_INT9   	B    PHANTOM	; User S/W Interrupt
SW_INT10  	B    PHANTOM	; User S/W Interrupt
SW_INT11  	B    PHANTOM	; User S/W Interrupt
SW_INT12  	B    PHANTOM	; User S/W Interrupt
SW_INT13  	B    PHANTOM	; User S/W Interrupt
SW_INT14  	B    PHANTOM	; User S/W Interrupt
SW_INT15  	B    PHANTOM	; User S/W Interrupt
SW_INT16  	B    PHANTOM	; User S/W Interrupt
TRAP	  	B    PHANTOM	; Trap vector
NMINT	  	B    PHANTOM	; Non-maskable Interrupt
EMU_TRAP  	B    PHANTOM	; Emulator Trap
SW_INT20  	B    PHANTOM	; User S/W Interrupt
SW_INT21  	B    PHANTOM	; User S/W Interrupt
SW_INT22  	B    PHANTOM	; User S/W Interrupt
SW_INT23  	B    PHANTOM	; User S/W Interrupt

;===========================================================
; M A I N   C O D E  - starts here
;===========================================================
		.text
		NOP
START:	SETC	INTM    		;Disable interrupts
		SPLK	#0000h,IMR	;Mask all core interrupts
		LACC	IFR		;Read Interrupt flags
		SACL	IFR		;Clear all interrupt flags

		CLRC	SXM		;Clear Sign Extension Mode
		CLRC	OVM		;Reset Overflow Mode
		CLRC	CNF		;Config Block B0 to Data mem

		LDP  #00E0h		;DP for addresses 7000h-707Fh
		SPLK #00BBh,CKCR1	;CLKIN(OSC)=10MHz,CPUCLK=20MHz
		SPLK #00C3h,CKCR0	;CLKMD=PLL Enable,SYSCLK =
                              		;CPUCLK/2
		SPLK  #40C0h,SYSCR	;CLKOUT=CPUCLK

		SPLK	#006Fh, WDCR	;Disable WD if VCCP=5V(JP52-3)
		KICK_DOG		;Reset Watchdog

		SPLK  #0h,GPR0		;Set wait state generator for:
		OUT   GPR0,WSGR     	;Program Space, 0 wait states
					;Data Space, 0 wait states
					;I/O Space, 0 wait states

		LARP	1		;Select AR1 as the current AR 
		LAR	AR1,#TABLEB     ;Load the starting address of
                              		;the destination table in AR1
		RPT	#COUNT		;Perform the following 
                              		;operation 10 times
		BLDD	#TABLEA,*+	;Transfer data from TABLEA to 
                              		;TABLEB. After the 
                              		;instruction, pointers to data
                              		;in both the tables are 
                              		;incremented.

END		B	END		;End Program

;===========================================================; 
;I S R  -  PHANTOM
; Description:	Dummy ISR, used to trap spurious interrupts.
; Modifies:	Nothing
;=========================================================== 
PHANTOM 	KICK_DOG		;Resets WD counter
		B	PHANTOM
