;*********************************************************************
; File Name:	 ch2_e6.asm
; Target System: C240x Evaluation Board
; Description:	 Conditional assembly using .if/.elseif/.else/.endif
;		 		directives. Perform adding, subtraction, multiplication
;		 		conditionally based on value of TEMP
; Date:			12/26/2003
; Author:		Min Dai
;*********************************************************************

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Global symbol declarations
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        .def _c_int0,PHANTOM,GISR1,GISR2,GISR3,GISR4,GISR5,GISR6

TEMP	.set	2			; set value of TEMP
var1	.set	000eh		; set value of var1, used as an address
var2	.set	000fh		; set value of var2, used as an address
res	  	.set	0010h		; set value of res, used as an address
one	  	.set	1			; set value of one
two	  	.set	2			; set value of two


;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Address definitions
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        .include f2407.h

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Uninitialized global variable definitions
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        .bss    GPR0,1         	;general purpose variable

;=====================================================================
; M A I N   C O D E  - starts here
;=====================================================================
		.text  
_c_int0
		NOP
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Configure the System Control and Status Registers
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        LDP     #DP_PF1         ;set data page

        SPLK    #0000000011111101b, SCSR1
*                ||||||||||||||||
*                FEDCBA9876543210
* bit 15        0:      reserved
* bit 14        0:      CLKOUT = CPUCLK
* bit 13-12     00:     IDLE1 selected for low-power mode
* bit 11-9      000:    PLL x4 mode
* bit 8         0:      reserved
* bit 7         1:      1 = enable ADC module clock
* bit 6         1:      1 = enable SCI module clock
* bit 5         1:      1 = enable SPI module clock
* bit 4         1:      1 = enable CAN module clock
* bit 3         1:      1 = enable EVB module clock
* bit 2         1:      1 = enable EVA module clock
* bit 1         0:      reserved
* bit 0         1:      clear the ILLADR bit

        LACC    SCSR2                   ;ACC = SCSR2 register
        OR      #0000000000001011b      ;OR in bits to be set
        AND     #0000000000001111b      ;AND out bits to be cleared
*                ||||||||||||||||
*                FEDCBA9876543210
* bit 15-6      0's:    reserved
* bit 5         0:      do NOT clear the WD OVERRIDE bit
* bit 4         0:      XMIF_HI-Z, 0=normal mode, 1=Hi-Z'd
* bit 3         1:      disable the boot ROM, enable the FLASH
* bit 2     no change   MP/MC* bit reflects the state of the MP/MC* pin
* bit 1-0      11:      11 = SARAM mapped to prog and data (default)

        SACL    SCSR2                   ;store to SCSR2 register

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Other setup
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Setup the core interrupts
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        LDP     #0h                     ;set data page
        SPLK    #0h,IMR                 ;clear the IMR register
        SPLK    #111111b,IFR            ;clear any pending core interrupts
        SPLK    #000100b,IMR            ;enable desired core interrupts

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Setup the event manager interrupts
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        LDP     #DP_EVA                 ;set data page
        SPLK    #0FFFFh, EVAIFRA        ;clear all EVA group A interrupts
        SPLK    #0FFFFh, EVAIFRB        ;clear all EVA group B interrupts
        SPLK    #0FFFFh, EVAIFRC        ;clear all EVA group C interrupts
        SPLK    #00000h, EVAIMRA        ;enabled desired EVA group A interrupts
        SPLK    #00001h, EVAIMRB        ;enabled desired EVA group B interrupts
        SPLK    #00000h, EVAIMRC        ;enabled desired EVA group C interrupts

        LDP     #DP_EVB                 ;set data page
        SPLK    #0FFFFh, EVBIFRA        ;clear all EVB group A interrupts
        SPLK    #0FFFFh, EVBIFRB        ;clear all EVB group B interrupts
        SPLK    #0FFFFh, EVBIFRC        ;clear all EVB group C interrupts
        SPLK    #00000h, EVBIMRA        ;enabled desired EVB group A interrupts
        SPLK    #00000h, EVBIMRB        ;enabled desired EVB group B interrupts
        SPLK    #00000h, EVBIMRC        ;enabled desired EVB group C interrupts

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Enable global interrupts
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        CLRC    INTM                    ;enable global interrupts



;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Disable the watchdog timer
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        LDP     #DP_PF1                 ;set data page

        SPLK    #0000000011101000b, WDCR
*                ||||||||||||||||
*                FEDCBA9876543210
* bits 15-8     0's      reserved
* bit 7         1:       clear WD flag
* bit 6         1:       disable the dog
* bit 5-3       101:     must be written as 101
* bit 2-0       000:     WDCLK divider = 1

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;Setup external memory interface for LF2407 EVM
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        LDP     #GPR0                  ;set current data page to 
        								;the data page of variable GPR0

        SPLK    #0000000001000000b, GPR0
*                ||||||||||||||||
*                FEDCBA9876543210
* bit 15-11     0's:    reserved
* bit 10-9      00:     bus visibility off
* bit 8-6       001:    1 wait-state for I/O space
* bit 5-3       000:    0 wait-state for data space
* bit 2-0       000:    0 wait state for program space

        OUT     GPR0, WSGR


			LDP      #0100h 	;Load Data Pointer 
     		SPLK  	 #0004h,var1
     		SPLK  	 #0003h,var2	
lbl_if:     .if	 TEMP = one	
      		LACC     var1
      		ADD      var2		  
      		SACL     res		;res = var1 + var2
           	.elseif  TEMP = two	
 	      	LACC     var1
 	      	SUB      var2		
      		SACL     res		;res = var1 - var2
      		.else 		
      		LT	 var1
      		MPY	 var2
           	SPL	 res			;res = var1 * var2	    
   	      	.endif	

END		B	END

;=====================================================================
; I S R  -  PHANTOM and unused GISRs
;
; Description:	Dummy ISR, used to trap spurious interrupts.
;
; Modifies:	Nothing
;=====================================================================
PHANTOM 	B	PHANTOM 
GISR1		RET 
GISR2		RET
GISR3		RET
GISR4		RET
GISR5		RET
GISR6		RET
